pub struct CommitParams {
pub repo: Option<String>,
pub commit: String,
}Fields
repo: Option<String>commit: StringTrait Implementations
Sourceimpl Debug for CommitParams
impl Debug for CommitParams
Sourceimpl<'de> Deserialize<'de> for CommitParams
impl<'de> Deserialize<'de> for CommitParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CommitParams
impl JsonSchema for CommitParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommitParams
impl RefUnwindSafe for CommitParams
impl Send for CommitParams
impl Sync for CommitParams
impl Unpin for CommitParams
impl UnsafeUnpin for CommitParams
impl UnwindSafe for CommitParams