pub struct DiffParams {
pub repo: Option<String>,
pub from_ref: String,
pub to_ref: Option<String>,
pub path: Option<String>,
}Fields
repo: Option<String>from_ref: Stringto_ref: Option<String>path: Option<String>Trait Implementations
Sourceimpl Debug for DiffParams
impl Debug for DiffParams
Sourceimpl<'de> Deserialize<'de> for DiffParams
impl<'de> Deserialize<'de> for DiffParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DiffParams
impl JsonSchema for DiffParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiffParams
impl RefUnwindSafe for DiffParams
impl Send for DiffParams
impl Sync for DiffParams
impl Unpin for DiffParams
impl UnsafeUnpin for DiffParams
impl UnwindSafe for DiffParams