pub struct FileAtRefParams {
pub repo: Option<String>,
pub path: String,
pub rev: Option<String>,
}Fields
repo: Option<String>path: Stringrev: Option<String>Trait Implementations
Sourceimpl Debug for FileAtRefParams
impl Debug for FileAtRefParams
Sourceimpl<'de> Deserialize<'de> for FileAtRefParams
impl<'de> Deserialize<'de> for FileAtRefParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FileAtRefParams
impl JsonSchema for FileAtRefParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FileAtRefParams
impl RefUnwindSafe for FileAtRefParams
impl Send for FileAtRefParams
impl Sync for FileAtRefParams
impl Unpin for FileAtRefParams
impl UnsafeUnpin for FileAtRefParams
impl UnwindSafe for FileAtRefParams